.. zope.pytest documentation master file, created by
   sphinx-quickstart on Thu Jan  6 13:39:53 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to zope.pytest's documentation!
=======================================

Contents:

.. toctree::
   :maxdepth: 2

   intro
   samples
   grok_samples
   api
   community
   development
   changes
   license
   copyright

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

